@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -223,7 +223,7 @@ int gmx_dyndom(int argc, char *argv[])
 
     printf("Select group to rotate:\n");
     rd_index(ftp2fn(efNDX, NFILE, fnm), 1, &isize, &index, &grpname);
-    printf("Going to rotate %s containg %d atoms\n", grpname, isize);
+    printf("Going to rotate %s containing %d atoms\n", grpname, isize);
 
     snew(index_all, atoms.nr);
     for (i = 0; (i < atoms.nr); i++)
