@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015,2016, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -193,7 +193,7 @@ int gmx_spol(int argc, char *argv[])
     static real     rmin   = 0.0, rmax = 0.32, refdip = 0, bw = 0.01;
     t_pargs         pa[]   = {
         { "-com",  FALSE, etBOOL,  {&bCom},
-          "Use the center of mass as the reference postion" },
+          "Use the center of mass as the reference position" },
         { "-refat",  FALSE, etINT, {&srefat},
           "The reference atom of the solvent molecule" },
         { "-rmin",  FALSE, etREAL, {&rmin}, "Maximum distance (nm)" },
