@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2016, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -147,7 +147,7 @@ void init_disres(FILE *fplog, const gmx_mtop_t *mtop,
             fprintf(fplog, "%s\n", notestr);
         }
 
-        if (dd->dr_tau != 0 || ir->eDisre == edrEnsemble || cr->ms != NULL ||
+        if (dd->dr_tau != 0 || ir->eDisre == edrEnsemble ||
             dd->nres != dd->npair)
         {
             gmx_fatal(FARGS, "Time or ensemble averaged or multiple pair distance restraints do not work (yet) with domain decomposition, use a single MPI rank%s", cr->ms ? " per simulation" : "");
