@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2014,2015, by the GROMACS development team, led by
+ * Copyright (c) 2014,2015,2016, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -109,7 +109,7 @@ void DataFileFinder::setSearchPathFromEnv(const char *envVarName)
     }
     impl_->envName_ = envVarName;
     const char *const lib = getenv(envVarName);
-    if (lib != NULL)
+    if (!isNullOrEmpty(lib))
     {
         impl_->bEnvIsSet_ = true;
         Path::splitPathEnvironment(lib, &impl_->searchPath_);
